"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findFanoutMintPda = exports.getFanoutMintSize = exports.getFanoutMintGpaBuilder = exports.safeFetchAllFanoutMint = exports.fetchAllFanoutMint = exports.safeFetchFanoutMint = exports.fetchFanoutMint = exports.deserializeFanoutMint = exports.getFanoutMintAccountDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getFanoutMintAccountDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['mint', s.publicKey()],
        ['fanout', s.publicKey()],
        ['tokenAccount', s.publicKey()],
        ['totalInflow', s.u64()],
        ['lastSnapshotAmount', s.u64()],
        ['bumpSeed', s.u8()],
    ], { description: 'FanoutMint' }), (value) => ({
        ...value,
        discriminator: [117, 125, 188, 123, 180, 213, 133, 164],
    }));
}
exports.getFanoutMintAccountDataSerializer = getFanoutMintAccountDataSerializer;
function deserializeFanoutMint(context, rawAccount) {
    return (0, umi_core_1.deserializeAccount)(rawAccount, getFanoutMintAccountDataSerializer(context));
}
exports.deserializeFanoutMint = deserializeFanoutMint;
async function fetchFanoutMint(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_core_1.assertAccountExists)(maybeAccount, 'FanoutMint');
    return deserializeFanoutMint(context, maybeAccount);
}
exports.fetchFanoutMint = fetchFanoutMint;
async function safeFetchFanoutMint(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeFanoutMint(context, maybeAccount)
        : null;
}
exports.safeFetchFanoutMint = safeFetchFanoutMint;
async function fetchAllFanoutMint(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_core_1.assertAccountExists)(maybeAccount, 'FanoutMint');
        return deserializeFanoutMint(context, maybeAccount);
    });
}
exports.fetchAllFanoutMint = fetchAllFanoutMint;
async function safeFetchAllFanoutMint(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeFanoutMint(context, maybeAccount));
}
exports.safeFetchAllFanoutMint = safeFetchAllFanoutMint;
function getFanoutMintGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.get('mplHydra').publicKey;
    return (0, umi_core_1.gpaBuilder)(context, programId)
        .registerFields([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['mint', s.publicKey()],
        ['fanout', s.publicKey()],
        ['tokenAccount', s.publicKey()],
        ['totalInflow', s.u64()],
        ['lastSnapshotAmount', s.u64()],
        ['bumpSeed', s.u8()],
    ])
        .deserializeUsing((account) => deserializeFanoutMint(context, account))
        .whereField('discriminator', [117, 125, 188, 123, 180, 213, 133, 164]);
}
exports.getFanoutMintGpaBuilder = getFanoutMintGpaBuilder;
function getFanoutMintSize(_context = {}) {
    return 200;
}
exports.getFanoutMintSize = getFanoutMintSize;
function findFanoutMintPda(context, seeds) {
    const s = context.serializer;
    const programId = context.programs.get('mplHydra').publicKey;
    return context.eddsa.findPda(programId, [
        s.string({ size: 'variable' }).serialize('fanout-config'),
        s.publicKey().serialize(seeds.fanout),
        s.publicKey().serialize(seeds.mint),
    ]);
}
exports.findFanoutMintPda = findFanoutMintPda;
//# sourceMappingURL=fanoutMint.js.map