"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addMemberNft = exports.getAddMemberNftInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getAddMemberNftInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['shares', s.u64()],
    ], { description: 'AddMemberNftInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [92, 255, 105, 209, 25, 41, 3, 7],
    }));
}
exports.getAddMemberNftInstructionDataSerializer = getAddMemberNftInstructionDataSerializer;
function addMemberNft(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('mplHydra').publicKey;
    const authorityAccount = input.authority ?? context.identity;
    const fanoutAccount = input.fanout;
    const membershipAccountAccount = input.membershipAccount;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_core_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(authorityAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: membershipAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(membershipAccountAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getAddMemberNftInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.addMemberNft = addMemberNft;
//# sourceMappingURL=addMemberNft.js.map