"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.distributeToken = exports.getDistributeTokenInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getDistributeTokenInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['distributeForMint', s.bool()],
    ], { description: 'DistributeTokenInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [126, 105, 46, 135, 28, 36, 117, 212],
    }));
}
exports.getDistributeTokenInstructionDataSerializer = getDistributeTokenInstructionDataSerializer;
function distributeToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('mplHydra').publicKey;
    const payerAccount = input.payer ?? context.payer;
    const memberAccount = input.member;
    const membershipMintTokenAccountAccount = input.membershipMintTokenAccount;
    const membershipVoucherAccount = input.membershipVoucher;
    const fanoutAccount = input.fanout;
    const holdingAccountAccount = input.holdingAccount;
    const fanoutForMintAccount = input.fanoutForMint;
    const fanoutForMintMembershipVoucherAccount = input.fanoutForMintMembershipVoucher;
    const fanoutMintAccount = input.fanoutMint;
    const fanoutMintMemberTokenAccountAccount = input.fanoutMintMemberTokenAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_core_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    const membershipMintAccount = input.membershipMint;
    const memberStakeAccountAccount = input.memberStakeAccount;
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: memberAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(memberAccount, true),
    });
    keys.push({
        pubkey: membershipMintTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(membershipMintTokenAccountAccount, true),
    });
    keys.push({
        pubkey: membershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(membershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: holdingAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(holdingAccountAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutForMintAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintMembershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutForMintMembershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutMintAccount, false),
    });
    keys.push({
        pubkey: fanoutMintMemberTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutMintMemberTokenAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: membershipMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(membershipMintAccount, true),
    });
    keys.push({
        pubkey: memberStakeAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(memberStakeAccountAccount, true),
    });
    const data = getDistributeTokenInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.distributeToken = distributeToken;
//# sourceMappingURL=distributeToken.js.map