"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.distributeWallet = exports.getDistributeWalletInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getDistributeWalletInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['distributeForMint', s.bool()],
    ], { description: 'DistributeWalletInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [252, 168, 167, 66, 40, 201, 182, 163],
    }));
}
exports.getDistributeWalletInstructionDataSerializer = getDistributeWalletInstructionDataSerializer;
function distributeWallet(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('mplHydra').publicKey;
    const payerAccount = input.payer ?? context.payer;
    const memberAccount = input.member;
    const membershipVoucherAccount = input.membershipVoucher;
    const fanoutAccount = input.fanout;
    const holdingAccountAccount = input.holdingAccount;
    const fanoutForMintAccount = input.fanoutForMint;
    const fanoutForMintMembershipVoucherAccount = input.fanoutForMintMembershipVoucher;
    const fanoutMintAccount = input.fanoutMint;
    const fanoutMintMemberTokenAccountAccount = input.fanoutMintMemberTokenAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_core_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: memberAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(memberAccount, true),
    });
    keys.push({
        pubkey: membershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(membershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: holdingAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(holdingAccountAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutForMintAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintMembershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutForMintMembershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutMintAccount, false),
    });
    keys.push({
        pubkey: fanoutMintMemberTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutMintMemberTokenAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getDistributeWalletInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.distributeWallet = distributeWallet;
//# sourceMappingURL=distributeWallet.js.map