"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initForMint = exports.getInitForMintInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getInitForMintInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['bumpSeed', s.u8()],
    ], { description: 'InitForMintInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [140, 150, 232, 195, 93, 219, 35, 170],
    }));
}
exports.getInitForMintInstructionDataSerializer = getInitForMintInstructionDataSerializer;
function initForMint(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('mplHydra').publicKey;
    const authorityAccount = input.authority ?? context.identity;
    const fanoutAccount = input.fanout;
    const fanoutForMintAccount = input.fanoutForMint;
    const mintHoldingAccountAccount = input.mintHoldingAccount;
    const mintAccount = input.mint;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.get('splSystem').publicKey,
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_core_1.publicKey)('SysvarRent111111111111111111111111111111111');
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(authorityAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(fanoutForMintAccount, true),
    });
    keys.push({
        pubkey: mintHoldingAccountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintHoldingAccountAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(rentAccount, false),
    });
    const data = getInitForMintInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.initForMint = initForMint;
//# sourceMappingURL=initForMint.js.map